@@ -1,4 +1,3 @@
-#!/usr/bin/perl
 package Test::Mojibake;
 # ABSTRACT: check your source for encoding misbehavior.
 
@@ -7,9 +6,8 @@ use strict;
 use utf8;
 use warnings 'all';
 
-our $VERSION = '0.3';
+our $VERSION = '0.4'; # VERSION
 
-use 5.008;
 use File::Spec;
 use Test::Builder;
 
@@ -168,7 +166,7 @@ sub all_files {
                 my $filename = File::Spec->catfile($file, $newfile);
                 if (-f $filename) {
                     push @queue, $filename;
-                }else {
+                } else {
                     push @queue, File::Spec->catdir($file, $newfile);
                 }
             }
@@ -246,14 +244,19 @@ sub _detect_utf8 {
                 return 0;
             }
 
+            my @buf = ((0) x 4, $c & ((1 << (6 - $bits)) - 1));
             while ($bits > 1) {
                 $i++;
                 $b = ord(substr(${$str}, $i, 1));
                 if (($b < 128) || ($b > 191)) {
                     return 0;
                 }
+                $buf[7 - $bits] = $b & 0x3f;
                 $bits--;
             }
+            return 0 if "\0\0\0\0\0\x2f" eq pack 'c6', @buf;
+        } elsif ($c == 0) {
+            return 0;
         }
     }
 
@@ -274,7 +277,7 @@ Test::Mojibake - check your source for encoding misbehavior.
 
 =head1 VERSION
 
-version 0.3
+version 0.4
 
 =head1 SYNOPSIS
 
@@ -486,7 +489,7 @@ Stanislaw Pusep <stas@sysd.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Stanislaw Pusep.
+This software is copyright (c) 2012 by Stanislaw Pusep.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
